/**
 * <p>File: Caesar.java</p>
 * <p>Title: Cryptography</p>
 * <p>Description: Course on introduction to typography</p>
 * <p>Date: March 2015</p>
 * @author Faton M. Berisha
 * @version 1.0.0
 */

package cryptography;

/**
 * Shift cipher cryptographic model. (Generalized Ceaser's cipher.)
 * 
 * @author Faton M. Berisha
 *
 */
public class Caesar {
	/**
	 * Shift cipher encryption algorithm.
	 * 
	 * @param message
	 *            message to encrypt
	 * @param key
	 *            encryption (shift) key
	 * @return encrypted message
	 */
	public String encrypt(String message, int key) {
		StringBuffer code = new StringBuffer();
		for (int i = 0; i < message.length(); i++) {
			char ch = message.charAt(i);
			if ((ch >= 'a' && ch <= 'z') || (ch >= 'A' && ch <= 'Z')) {
				int c = (Character.toUpperCase(ch) - 'A' + key) % 26;
				if (c < 0) {
					c += 26;
				}
				c += 'A';
				code.append((char) c);
			}
		}
		return new String(code);
	}

	/**
	 * Shift cipher decryption algorithm.
	 * 
	 * @param code
	 *            encrypted code to decrypt
	 * @param key
	 *            decryption (shift back) key
	 * @return decrypted message
	 */
	public String decrypt(String code, int key) {
		StringBuffer message = new StringBuffer();
		for (int i = 0; i < code.length(); i++) {
			char c = code.charAt(i);
			int temp = (Character.toUpperCase(c) - 'A' - key) % 26;
			if (temp < 0) {
				temp += 26;
			}
			temp += 'A';
			message.append((char) temp);
		}
		return new String(message);
	}
}
